==> accounting-manager-1.14.0-20210628.172858-3-sources.jar: org/gcube/portlets/admin/accountingmanager/client/maindata/charts/AccountingChart4Storage.java <==
package org.gcube.portlets.admin.accountingmanager.client.maindata.charts;

import org.gcube.portlets.admin.accountingmanager.client.maindata.charts.storage.StorageChartBasicPanel;
import org.gcube.portlets.admin.accountingmanager.client.maindata.charts.storage.StorageChartContextPanel;
import org.gcube.portlets.admin.accountingmanager.client.maindata.charts.storage.StorageChartTopPanel;
import org.gcube.portlets.admin.accountingmanager.client.state.AccountingClientStateData;
import org.gcube.portlets.admin.accountingmanager.shared.data.response.SeriesStorage;
import org.gcube.portlets.admin.accountingmanager.shared.exception.ChartDrawException;

import com.google.gwt.event.shared.EventBus;
import com.sencha.gxt.widget.core.client.container.SimpleContainer;

/**
 * Accounting Chart 4 Storage
 * 
   * @author Giancarlo Panichi
 *
 * 
 */
public class AccountingChart4Storage extends AccountingChartBuilder {
	private EventBus eventBus;
	private AccountingClientStateData accountingStateData;

	public AccountingChart4Storage(EventBus eventBus,
			AccountingClientStateData accountingStateData) {
		this.eventBus = eventBus;
		this.accountingStateData = accountingStateData;
	}

	@Override
	public void buildChart() throws ChartDrawException {
		AccountingChartPanel accountingChartPanel = null;

		if (accountingStateData == null
				|| accountingStateData.getAccountingType() == null
				|| accountingStateData.getSeriesRequest() == null
				|| accountingStateData.getSeriesResponse() == null) {
			accountingChartSpec.setChart(accountingChartPanel);
			return;
		}

		if (!(accountingStateData.getSeriesResponse() instanceof SeriesStorage)) {
			accountingChartSpec.setChart(accountingChartPanel);
			return;
		}

		SimpleContainer container = createStorageChartPanel();

		accountingChartPanel = new AccountingChartPanel(container);

		accountingChartSpec.setChart(accountingChartPanel);

	}

	private SimpleContainer createStorageChartPanel() throws ChartDrawException {

		if (accountingStateData == null
				|| accountingStateData.getSeriesRequest() == null
				|| accountingStateData.getSeriesRequest()
						.getAccountingFilterDefinition() == null
				|| accountingStateData.getSeriesRequest()
						.getAccountingFilterDefinition().getChartType() == null) {
			return null;
		}

		switch (accountingStateData.getSeriesRequest()
				.getAccountingFilterDefinition().getChartType()) {

		case Top:
			return new StorageChartTopPanel(eventBus, accountingStateData);
		case Basic:
			return new StorageChartBasicPanel(eventBus, accountingStateData);
		case Context:
			return new StorageChartContextPanel(eventBus, accountingStateData);

		default:

			return null;
		}

	}

}

==> accounting-manager-1.15.0-20211130.133846-3-sources.jar: org/gcube/portlets/admin/accountingmanager/client/maindata/charts/AccountingChart4Storage.java <==
package org.gcube.portlets.admin.accountingmanager.client.maindata.charts;

import org.gcube.portlets.admin.accountingmanager.client.maindata.charts.storage.StorageChartBasicPanel;
import org.gcube.portlets.admin.accountingmanager.client.maindata.charts.storage.StorageChartTopPanel;
import org.gcube.portlets.admin.accountingmanager.client.state.AccountingClientStateData;
import org.gcube.portlets.admin.accountingmanager.shared.data.response.SeriesStorage;
import org.gcube.portlets.admin.accountingmanager.shared.exception.ChartDrawException;

import com.google.gwt.event.shared.EventBus;
import com.sencha.gxt.widget.core.client.container.SimpleContainer;

/**
 * Accounting Chart 4 Storage
 * 
 * @author Giancarlo Panichi
 *
 * 
 */
public class AccountingChart4Storage extends AccountingChartBuilder {
	private EventBus eventBus;
	private AccountingClientStateData accountingStateData;

	public AccountingChart4Storage(EventBus eventBus, AccountingClientStateData accountingStateData) {
		this.eventBus = eventBus;
		this.accountingStateData = accountingStateData;
	}

	@Override
	public void buildChart() throws ChartDrawException {
		AccountingChartPanel accountingChartPanel = null;

		if (accountingStateData == null || accountingStateData.getAccountingType() == null
				|| accountingStateData.getSeriesRequest() == null || accountingStateData.getSeriesResponse() == null) {
			accountingChartSpec.setChart(accountingChartPanel);
			return;
		}

		if (!(accountingStateData.getSeriesResponse() instanceof SeriesStorage)) {
			accountingChartSpec.setChart(accountingChartPanel);
			return;
		}

		SimpleContainer container = createStorageChartPanel();

		accountingChartPanel = new AccountingChartPanel(container);

		accountingChartSpec.setChart(accountingChartPanel);

	}

	private SimpleContainer createStorageChartPanel() throws ChartDrawException {

		if (accountingStateData == null || accountingStateData.getSeriesRequest() == null
				|| accountingStateData.getSeriesRequest().getAccountingFilterDefinition() == null
				|| accountingStateData.getSeriesRequest().getAccountingFilterDefinition().getChartType() == null) {
			return null;
		}

		switch (accountingStateData.getSeriesRequest().getAccountingFilterDefinition().getChartType()) {

		case Top:
			return new StorageChartTopPanel(eventBus, accountingStateData);
		case Basic:
			return new StorageChartBasicPanel(eventBus, accountingStateData);
		default:

			return null;
		}

	}

}
